Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: components/exo/wm_helper_mus.h

Issue 2714763002: Change FocusSynchronizer to maintain active focus client and window. (Closed)
Patch Set: test Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/exo/wm_helper_mus.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/exo/wm_helper_mus.h
diff --git a/components/exo/wm_helper_mus.h b/components/exo/wm_helper_mus.h
index f1fb4cc73927eee2a836c7ae4169560354f17bb7..a74f65c0b1261825b650410d41cb98e8b48f39c0 100644
--- a/components/exo/wm_helper_mus.h
+++ b/components/exo/wm_helper_mus.h
@@ -8,7 +8,7 @@
#include "base/macros.h"
#include "components/exo/wm_helper.h"
#include "ui/aura/client/focus_change_observer.h"
-#include "ui/aura/env_observer.h"
+#include "ui/aura/mus/focus_synchronizer_observer.h"
#include "ui/events/devices/input_device_event_observer.h"
namespace aura {
@@ -22,7 +22,7 @@ namespace exo {
// A helper class for accessing WindowManager related features.
class WMHelperMus : public WMHelper,
public ui::InputDeviceEventObserver,
- public aura::EnvObserver,
+ public aura::FocusSynchronizerObserver,
public aura::client::FocusChangeObserver {
public:
WMHelperMus();
@@ -44,10 +44,9 @@ class WMHelperMus : public WMHelper,
bool IsSpokenFeedbackEnabled() const override;
void PlayEarcon(int sound_key) const override;
- // Overriden from aura::EnvObserver:
- void OnWindowInitialized(aura::Window* window) override;
+ // Overriden from aura::FocusSynchronizerObserver:
void OnActiveFocusClientChanged(aura::client::FocusClient* focus_client,
- aura::Window* window) override;
+ aura::Window* focus_client_root) override;
// Overriden from ui::client::FocusChangeObserver:
void OnWindowFocused(aura::Window* gained_focus,
« no previous file with comments | « no previous file | components/exo/wm_helper_mus.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698